@@ -10,7 +10,7 @@ The Eclipse Public License is available at
 and the Eclipse Distribution License is available at
   http://www.eclipse.org/org/documents/edl-v10.php.
 
-SPDX-License-Identifier: EPL-2.0 OR EDL-1.0
+SPDX-License-Identifier: EPL-2.0 OR BSD-3-Clause
 
 Contributors:
    Roger Light - initial implementation and documentation.
@@ -124,6 +124,37 @@ static void print_list(cJSON *j_response, const char *arrayname, const char *key
 }
 
 
+static void print_roles(cJSON *j_roles, size_t slen)
+{
+	bool first;
+	cJSON *j_elem, *jtmp;
+
+	if(j_roles && cJSON_IsArray(j_roles)){
+		first = true;
+		cJSON_ArrayForEach(j_elem, j_roles){
+			jtmp = cJSON_GetObjectItem(j_elem, "rolename");
+			if(jtmp && cJSON_IsString(jtmp)){
+				if(first){
+					first = false;
+					printf("%-*s %s", (int)slen, "Roles:", jtmp->valuestring);
+				}else{
+					printf("%-*s %s", (int)slen, "", jtmp->valuestring);
+				}
+				jtmp = cJSON_GetObjectItem(j_elem, "priority");
+				if(jtmp && cJSON_IsNumber(jtmp)){
+					printf(" (priority: %d)", (int)jtmp->valuedouble);
+				}else{
+					printf(" (priority: -1)");
+				}
+				printf("\n");
+			}
+		}
+	}else{
+		printf("Roles:\n");
+	}
+}
+
+
 static void print_client(cJSON *j_response)
 {
 	cJSON *j_data, *j_client, *j_array, *j_elem, *jtmp;
@@ -161,29 +192,8 @@ static void print_client(cJSON *j_response)
 	}
 
 	j_array = cJSON_GetObjectItem(j_client, "roles");
-	if(j_array && cJSON_IsArray(j_array)){
-		first = true;
-		cJSON_ArrayForEach(j_elem, j_array){
-			jtmp = cJSON_GetObjectItem(j_elem, "rolename");
-			if(jtmp && cJSON_IsString(jtmp)){
-				if(first){
-					first = false;
-					printf("Roles:    %s", jtmp->valuestring);
-				}else{
-					printf("          %s", jtmp->valuestring);
-				}
-				jtmp = cJSON_GetObjectItem(j_elem, "priority");
-				if(jtmp && cJSON_IsNumber(jtmp)){
-					printf(" (priority: %d)", (int)jtmp->valuedouble);
-				}else{
-					printf(" (priority: -1)");
-				}
-				printf("\n");
-			}
-		}
-	}else{
-		printf("Roles:\n");
-	}
+	print_roles(j_array, strlen("Username:"));
+
 	j_array = cJSON_GetObjectItem(j_client, "groups");
 	if(j_array && cJSON_IsArray(j_array)){
 		first = true;
@@ -236,27 +246,7 @@ static void print_group(cJSON *j_response)
 	printf("Groupname: %s\n", jtmp->valuestring);
 
 	j_array = cJSON_GetObjectItem(j_group, "roles");
-	if(j_array && cJSON_IsArray(j_array)){
-		first = true;
-		cJSON_ArrayForEach(j_elem, j_array){
-			jtmp = cJSON_GetObjectItem(j_elem, "groupname");
-			if(jtmp && cJSON_IsString(jtmp)){
-				if(first){
-					first = false;
-					printf("Roles:  %s", jtmp->valuestring);
-				}else{
-					printf("    %s", jtmp->valuestring);
-				}
-				jtmp = cJSON_GetObjectItem(j_elem, "priority");
-				if(jtmp && cJSON_IsNumber(jtmp)){
-					printf(" (priority: %d)", (int)jtmp->valuedouble);
-				}else{
-					printf(" (priority: -1)");
-				}
-				printf("\n");
-			}
-		}
-	}
+	print_roles(j_array, strlen("Groupname:"));
 
 	j_array = cJSON_GetObjectItem(j_group, "clients");
 	if(j_array && cJSON_IsArray(j_array)){
@@ -393,7 +383,14 @@ static void dynsec__payload_callback(struct mosq_ctrl *ctrl, long payloadlen, co
 {
 	cJSON *tree, *j_responses, *j_response, *j_command, *j_error;
 
+	UNUSED(ctrl);
+
+#if CJSON_VERSION_FULL < 1007013
+	UNUSED(payloadlen);
 	tree = cJSON_Parse(payload);
+#else
+	tree = cJSON_ParseWithLength(payload, payloadlen);
+#endif
 	if(tree == NULL){
 		fprintf(stderr, "Error: Payload not JSON.\n");
 		return;
@@ -502,6 +499,9 @@ static int dynsec__set_default_acl_access(int argc, char *argv[], cJSON *j_comma
 
 static int dynsec__get_default_acl_access(int argc, char *argv[], cJSON *j_command)
 {
+	UNUSED(argc);
+	UNUSED(argv);
+
 	if(cJSON_AddStringToObject(j_command, "command", "getDefaultACLAccess") == NULL
 			){
 
@@ -721,9 +721,8 @@ int dynsec_init(int argc, char *argv[])
 		snprintf(verify_prompt, sizeof(verify_prompt), "Reenter password for %s: ", admin_user);
 		rc = get_password(prompt, verify_prompt, false, password, sizeof(password));
 		if(rc){
-			fprintf(stderr, "Error getting password.\n");
 			mosquitto_lib_cleanup();
-			return 1;
+			return -1;
 		}
 		admin_password = password;
 	}
