@@ -203,6 +203,13 @@ static int interruptible_sleep(struct mosquitto *mosq, time_t reconnect_delay)
 	char pairbuf;
 	int maxfd = 0;
 
+#ifndef WIN32
+	if(read(mosq->sockpairR, &pairbuf, 1) == 0){
+	}
+#else
+	recv(mosq->sockpairR, &pairbuf, 1, 0);
+#endif
+
 	local_timeout.tv_sec = reconnect_delay;
 #ifdef HAVE_PSELECT
 	local_timeout.tv_nsec = 0;
